==> SyL-0.14.9.tar.gz: SyL/include/lib/Validation/SyL_ValidationValidators.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.5 2008/01/15 09:19:03 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ڸ̥롼ץ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.5 2008/01/15 09:19:03 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ValidationValidators extends SyL_Validation
{
    /**
     * ̸ڥ饹ޤȤ᤿
     *
     * @access private
     * @var array
     */
    var $validators = array();

    /**
     * 롼׸ڥ֥Ȥμ
     *
     * @static
     * @access public
     * @return object 롼׸ڥ֥
     */
    function &create()
    {
        $classname = __CLASS__;
        $validators =& new $classname();
        return $validators;
    }

    /**
     * ̸ڥ֥Ȥɲä
     *
     * @access public
     * @param object ̸ڥ֥
     */
    function add(&$validator)
    {
        if (version_compare(PHP_VERSION, '5.0.0', '>=')) {
            $this->validators[] = unserialize(serialize($validator));
        } else {
            $this->validators[] = $validator;
        }
    }

    /**
     * ɬܥå¸Ƚ
     *
     * @access public
     * @return bool true: ɬܥåꡢfalse: ɬܥå̵
     */
    function isRequire()
    {
        foreach (array_keys($this->validators) as $key) {
            if ($this->validators[$key]->isRequire()) {
                return true;
            }
        }
        return false;
    }

    /**
     * ڽ¹Ԥ
     *
     * @access public
     * @param string о
     * @param string о̾
     * @return bool true: 顼̵, false: 顼
     */
    function execute($value, $name='')
    {
        foreach (array_keys($this->validators) as $key) {
            if (!$this->validators[$key]->execute($value, $name)) {
                $this->error_message = $this->validators[$key]->getErrorMessage();
                return false;
            }
        }
        return true;
    }

    /**
     * JavaScriptå
     *
     * @access public
     * @param string եɽ̾
     * @param array եǤradio, select, checkboxξΤߡ
     * @return string JavaScriptå
     */
    function getJs($display_name)
    {
        $js = '';
        foreach (array_keys($this->validators) as $key) {
            $js .= $this->validators[$key]->getJs($display_name);
        }
        return $js;
    }
}

/**
 * ꥢ
 */
class SyL_Validators extends SyL_ValidationValidators{}

?>

==> SyL-0.15.1.tar.gz: SyL/include/lib/Validation/SyL_ValidationValidators.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.6 2008/05/21 17:22:47 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ڸ̥롼ץ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.6 2008/05/21 17:22:47 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ValidationValidators extends SyL_Validation
{
    /**
     * ̸ڥ饹ޤȤ᤿
     *
     * @access private
     * @var array
     */
    var $validators = array();

    /**
     * 롼׸ڥ֥Ȥμ
     *
     * @static
     * @access public
     * @return object 롼׸ڥ֥
     */
    function &create()
    {
        $classname = __CLASS__;
        $validators =& new $classname();
        return $validators;
    }

    /**
     * ̸ڥ֥Ȥɲä
     *
     * @access public
     * @param object ̸ڥ֥
     */
    function add(&$validator)
    {
        if (version_compare(PHP_VERSION, '5.0.0', '>=')) {
            $this->validators[] = unserialize(serialize($validator));
        } else {
            $this->validators[] = $validator;
        }
    }

    /**
     * ɬܥå¸Ƚ
     *
     * @access public
     * @return bool true: ɬܥåꡢfalse: ɬܥå̵
     */
    function isRequire()
    {
        foreach (array_keys($this->validators) as $key) {
            if ($this->validators[$key]->isRequire()) {
                return true;
            }
        }
        return false;
    }

    /**
     * ڽ¹Ԥ
     *
     * @access public
     * @param string о
     * @param string о̾
     * @return bool true: 顼̵, false: 顼
     */
    function execute($value, $name='')
    {
        foreach (array_keys($this->validators) as $key) {
            if (!$this->validators[$key]->execute($value, $name)) {
                $this->error_message = $this->validators[$key]->getErrorMessage();
                return false;
            }
        }
        return true;
    }

    /**
     * JavaScriptå
     *
     * @access public
     * @param string եɽ̾
     * @param array եǤradio, select, checkboxξΤߡ
     * @return string JavaScriptå
     */
    function getJs($display_name)
    {
        $js = '';
        foreach (array_keys($this->validators) as $key) {
            $tmp = $this->validators[$key]->getJs($display_name);
            if ($tmp) {
                if ($this->validators[$key]->isRequire()) {
                    $js .= 'if (!message) {' . "\n";
                } else {
                    $js .= 'if (!message && !validation.isRequire(name, "require!")) {' . "\n";
                }
                $js .= $tmp . "\n";
                $js .= '}' . "\n";
            }
        }
        return $js;
    }
}

/**
 * ꥢ
 */
class SyL_Validators extends SyL_ValidationValidators{}

?>
